OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Vytvorili ste novú nástenku {board}",
    "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
    "You have deleted the board {board}" : "Vymazali ste nástenku {board}",
    "{user} has deleted the board {board}" : "Používateľ {user} vymazal nástenku {board}",
    "You have restored the board {board}" : "Obnovili ste nástenku {board}",
    "{user} has restored the board {board}" : "Používateľ {user} obnovil nástenku {board}",
    "You have shared the board {board} with {acl}" : "Sprístupnili ste nástenku {board} s {acl}",
    "{user} has shared the board {board} with {acl}" : "Používateľ {user} sprístupnil nástenku {board} pre {acl}",
    "You have removed {acl} from the board {board}" : "Odobrali ste {acl} z nástenky {board}",
    "{user} has removed {acl} from the board {board}" : "Používateľ {user} odobral {acl} z nástenky {board}",
    "You have renamed the board {before} to {board}" : "Premenovali ste nástenku {before} na {board}",
    "{user} has renamed the board {before} to {board}" : "Používateľ {user} premenoval nástenku {before} na {board}",
    "You have archived the board {board}" : "Archivovali ste nástenku {board}",
    "{user} has archived the board {before}" : "Používateľ {user} archivoval nástenku {board}",
    "You have unarchived the board {board}" : "Zrušili ste archiváciu nástenky {board}",
    "{user} has unarchived the board {before}" : "Používateľ {user} zrušil archiváciu nástenky {before}",
    "You have created a new stack {stack} on board {board}" : "Vytvorili ste nový stĺpec {stack} na nástenke {board}",
    "{user} has created a new stack {stack} on board {board}" : "Používateľ {user} vytvoril nový stĺpec {stack} na nástenke {board}",
    "You have renamed stack {before} to {stack} on board {board}" : "Premenovali ste stĺpec {before} na {stack} na nástenke {board}",
    "{user} has renamed stack {before} to {stack} on board {board}" : "Používateľ {user} premenoval stĺpec {before} na {stack} na nástenke {board}",
    "You have deleted stack {stack} on board {board}" : "Vymazali ste stĺpec {stack} z nástenky {board}",
    "{user} has deleted stack {stack} on board {board}" : "Používateľ {user} vymazal stĺpec {stack} z nástenky {board}",
    "You have created card {card} in stack {stack} on board {board}" : "Vytvorili ste kartu {card} v stĺpci {stack} na nástenke {board}",
    "{user} has created card {card} in stack {stack} on board {board}" : "Používateľ {user} vytvoril kartu {card} v stĺpci {stack} na nástenke {board}",
    "You have deleted card {card} in stack {stack} on board {board}" : "Vymazali ste kartu {card} v stĺpci {stack} z nástenky {board}",
    "{user} has deleted card {card} in stack {stack} on board {board}" : "Používateľ {user} vymazal kartu {card} v stĺpci {stack} z nástenky {board}",
    "You have renamed the card {before} to {card}" : "Premenovali ste kartu {before} na {card}",
    "{user} has renamed the card {before} to {card}" : "Používateľ {user} premenoval kartu {before} na {card}",
    "You have added a description to card {card} in stack {stack} on board {board}" : "Pridali ste popis ku karte {card} v stĺpci {stack} na nástenke {board}",
    "{user} has added a description to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal popis ku karte {card} v stĺpci {stack} na nástenke {board}",
    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali ste popis v karte {card} v stĺpci {stack} na nástenke {board}",
    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "Používateľ {user} aktualizoval popis karty {card} v stĺpci {stack} na nástenke {board}",
    "You have archived card {card} in stack {stack} on board {board}" : "Archivovali ste kartu {card} v stĺpci {stack} na nástenke {board}",
    "{user} has archived card {card} in stack {stack} on board {board}" : "Používateľ {user} archivoval kartu {card} v stĺpci {stack} na nástenke {board}",
    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v stĺpci {stack} na nástenke {board}",
    "{user} has unarchived card {card} in stack {stack} on board {board}" : "Používateľ {user} zrušil archiváciu karty {card} v stĺpci {stack} na nástenke {board}",
    "You have removed the due date of card {card}" : "Odobrali ste termín dokončenia z karty {card}",
    "{user} has removed the due date of card {card}" : "Používateľ {user} odobral termín dokončenia z karty {card}",
    "You have set the due date of card {card} to {after}" : "Nastavili ste termín dokončenia pre kartu {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "Používateľ {user} nastavil termín dokončenia karty {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Zmenili ste termín dokončenia karty {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "Používateľ {user} aktualizoval termín dokončenia karty {card} na {after}",
    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v stĺpci {stack} na nástenke {board}",
    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal štítok {label} ku karte {card} v stĺpci {stack} na nástenke {board}",
    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odobrali ste štítok {label} z karty {card} v stĺpci {stack} na nástenke {board}",
    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "Používateľ {user} odobral štítok {label} z karty {card} v stĺpci {stack} na nástenke {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Priradili ste používateľa {assigneduser} ku karte {card} na nástenke {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "Používateľ {user} priradil používateľa {assigneduser} ku karte {card} na nástenke {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Vyradili ste priradenie používateľa {assigneduser} z karty {card} na nástenke {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "Používateľ {user} vyradil používateľa {assigneduser} z karty {card} na nástenke {board}",
    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo stĺpca {stackBefore} do stĺpca {stack}",
    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "Používateľ {user} presunul kartu {card} zo stĺpca {stackBefore} do stĺpca {stack}",
    "You have added the attachment {attachment} to card {card}" : "Pridali ste prílohu {attachment} ku karte {card}",
    "{user} has added the attachment {attachment} to card {card}" : "Používateľ {user} pridal prílohu {attachment} ku karte {card}",
    "You have updated the attachment {attachment} on card {card}" : "Aktualizovali ste prílohu {attachment} na karte {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "Používateľ {user} aktualizoval prílohu {attachment} na karte {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Vymazali ste prílohu {attachment} na karte {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "Používateľ {user} vymazal prílohu {attachment} na karte {card}",
    "You have restored the attachment {attachment} to card {card}" : "Obnovili ste prílohu {attachment} na karte {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "Používateľ {user} obnovil prílohu {attachment} na karte {card}",
    "You have commented on card {card}" : "Komentovali ste kartu {card}",
    "{user} has commented on card {card}" : "{user} komentoval(a) kartu {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "V apke Nástenka sa zmenil <strong>Popis karty</strong>",
    "Deck" : "Nástenka",
    "Changes in the <strong>Deck app</strong>" : "Zmeny v apke <strong>Nástenka</strong>",
    "A <strong>comment</strong> was created on a card" : "Na karte bol vytvorený <strong>komentár</strong>. ",
    "Personal" : "Osobné",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "Používateľ {user} vám priradil kartu „%s“ na „%s“.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Karta \"%s\" na nástenke \"%s\" dosiahla termín dokončenia.",
    "%s has mentioned you in a comment on \"%s\"." : "Používateľ %s vás zmienil v komentári ku „%s“.",
    "{user} has mentioned you in a comment on \"%s\"." : "Používateľ {user} vás zmienil v komentári v „%s“.",
    "The board \"%s\" has been shared with you by %s." : "Používateľ %s vám sprístupnil nástenku \"%s\".",
    "{user} has shared the board %s with you." : "Používateľ {user} vám sprístupnil nástenku %s.",
    "No data was provided to create an attachment." : "Neboli poskytnuté dáta pre vytvorenie prílohy.",
    "Finished" : "Ukončené",
    "To review" : "Na posúdenie",
    "Action needed" : "Potrebná akcia",
    "Later" : "Neskôr",
    "copy" : "kopírovať",
    "To do" : "Urobiť",
    "Doing" : "Prebieha",
    "Done" : "Hotové",
    "Example Task 3" : "Príklad úlohy 3",
    "Example Task 2" : "Príklad úlohy 2",
    "Example Task 1" : "Príklad úlohy 1",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor bol nahraný iba čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
    "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
    "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
    "Personal planning and team project organization" : "Osobné plánovanie a organizácia tímových projektov",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
    "Create new board" : "Vytvoriť novú nástenku",
    "new board" : "nová nástenka",
    "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
    "Search by board title" : "Vyhľadávanie podľa názvu nástenky",
    "Select board" : "Vybrať nástenku",
    "Select the card to link to a project" : "Vyberte kartu, ktorú chcete prepojiť s projektom",
    "Select a board" : "Vyberte nástenku",
    "Select a card" : "Vyberte kartu",
    "Link to card" : "Prepojiť s kartou",
    "Cancel" : "Zrušiť",
    "File already exists" : "Súbor už existuje",
    "A file with the name {filename} already exists." : "Súbor s názvom {filename} už existuje.",
    "Do you want to overwrite it?" : "Chcete ho prepísať?",
    "Overwrite file" : "Prepísať súbor",
    "Keep existing file" : "Ponechať existujúci súbor",
    "This board is read only" : "Táto nástenka je iba na čítanie",
    "Drop your files to upload" : "Pretiahnite sem súbory, ktoré chcete nahrať",
    "Archived cards" : "Archivované karty",
    "Add new list" : "Pridať nový zoznam",
    "List name" : "Názov zoznamu",
    "Apply filter" : "Uplatniť filter",
    "Filter by tag" : "Filtrovať podľa štítkov",
    "Filter by assigned user" : "Filtrovať podľa priradeného používateľa",
    "Filter by due date" : "Filtrovať podľa termínu",
    "Overdue" : "Po termíne",
    "Next 24 hours" : "Ďalších 24 hodín",
    "Next 7 days" : "Následujúcich 7 dní",
    "Next 30 days" : "Následujúcich 30 dní",
    "No due date" : "Bez termínu",
    "Clear filter" : "Vyčistiť filter",
    "Show archived cards" : "Zobraziť archivované karty",
    "Toggle compact mode" : "Vyp/zap. kompaktný režim",
    "Details" : "Podrobnosti",
    "Loading board" : "Načítanie nástenky",
    "Board not found" : "Nástenka nebola nájdená",
    "Sharing" : "Sprístupnenie",
    "Tags" : "Štítky",
    "Deleted items" : "Zmazané položky",
    "Timeline" : "Časová os",
    "Deleted lists" : "Vymazané zoznamy",
    "Undo" : "Odvolať",
    "Deleted cards" : "Odstránené karty",
    "Share board with a user, group or circle …" : "Zdieľanie nástenky s použivateľom, skupinou alebo okruhom…",
    "Board owner" : "Vlastník nástenky",
    "(Group)" : "(Skupina)",
    "(Circle)" : "(Okruh)",
    "Can edit" : "Môže upravovať",
    "Can share" : "Môže sprístupniť",
    "Can manage" : "Môže spravovať",
    "Delete" : "Zmazať",
    "Add a new stack" : "Pridať nový stĺpec",
    "Delete list" : "Vymazať zoznam",
    "Add card" : "Pridať kartu",
    "Add a new card" : "Pridať novú kartu",
    "Edit" : "Upraviť",
    "Add a new tag" : "Pridať nový štítok",
    "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
    "Title" : "Názov",
    "Members" : "Členovia",
    "Add this attachment" : "Pridať túto prílohu",
    "Delete Attachment" : "Odstrániť prílohu",
    "Restore Attachment" : "Obnoviť prílohu",
    "Assign a tag to this card…" : "Tejto karte priradiť štítok…",
    "Assign to users" : "Priradiť používateľom",
    "Assign to users/groups/circles" : "Priradiť používateľom/skupinám/okruhom",
    "Assign a user to this card…" : "Priradiť používateľa k tejto karte…",
    "Due date" : "Termín dokončenia",
    "Set a due date" : "Nastaviť termín",
    "Remove due date" : "Odstrániť termín dokončenia",
    "Description" : "Popis",
    "(Unsaved)" : "(Neuložené)",
    "(Saving…)" : "(Ukladanie…)",
    "Formatting help" : "Pomoc pri formátovaní",
    "Add Attachment" : "Pridať prílohu",
    "Edit description" : "Upraviť popis",
    "View description" : "Zobraziť popis",
    "Attachments" : "Prílohy",
    "Comments" : "Komentáre",
    "Choose attachment" : "Vybrať prílohu",
    "Modified" : "Upravené",
    "Created" : "Vytvorené",
    "Upload attachment" : "Nahrať prílohu",
    "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
    "Save" : "Uložiť",
    "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
    "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
    "In reply to" : "Odpoveď na",
    "Reply" : "Odpoveď",
    "Update" : "Aktualizovať",
    "(group)" : "(skupina)",
    "(circle)" : "(okruh)",
    "seconds ago" : "pred niekoľkými sekundami",
    "Assign to me" : "Priradiť mne",
    "Unarchive card" : "Zrušiť archiváciu karty",
    "Archive card" : "Archivovať kartu",
    "Delete card" : "Zmazať kartu",
    "Move card" : "Presunúť kartu",
    "Card details" : "Podrobnosti o karte",
    "Move card to another board" : "Presunúť kartu na inú nástenku",
    "Select a stack" : "Vybrať stĺpec",
    "All boards" : "Všetky nástenky",
    "Archived boards" : "Archivované nástenky",
    "Shared with you" : "Vám sprístupnené",
    "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
    "Settings" : "Nastavenia",
    "New board title" : "Názov novej nástenky",
    "Edit board" : "Upraviť nástenku",
    "Clone board " : "Zdvojiť nástenku",
    "Unarchive board " : "Zrušiť archiváciu nástenky",
    "Archive board " : "Archivovať nástenku",
    "Delete board " : "Zmazať nástenku",
    "Board details" : "Podrobnosti o nástenke",
    "Board {0} deleted" : "Nástenka {0} vymazaná",
    "An error occurred" : "Vyskytla sa chyba",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
    "Delete the board?" : "Vymazať nástenku?",
    "Link to a board" : "Odkaz na nástenku",
    "Link to a card" : "Prepojiť s kartou",
    "Something went wrong" : "Niečo sa pokazilo",
    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
